@@ -115,7 +115,8 @@ def classify_columns(df_preds, verbose=0):
     if len(discrete_or_nlp_vars) > 0:
         for col in copy_discrete_or_nlp_vars:
             #### first fill empty or missing vals since it will blowup ###
-            train[col] = train[col].fillna('  ')
+            ### Remember that fillna only works at the dataframe level!
+            train[[col]] = train[[col]].fillna('  ')
             if train[col].map(lambda x: len(x) if type(x)==str else 0).max(
                 ) >= 50 and len(train[col].value_counts()
                         ) >= int(0.9*len(train)) and col not in string_bool_vars:
@@ -204,19 +205,35 @@ def classify_columns(df_preds, verbose=0):
     float_or_cat = var_df.apply(lambda x: 1 if x['type_of_column'] in ['float16',
                             'float32','float64'] else 0,
                                         axis=1)
+    #######  We need to make sure there are no categorical vars in float #######
     if len(var_df.loc[float_or_cat == 1]) > 0:
         for col in var_df.loc[float_or_cat == 1]['index'].values.tolist():
             if len(train[col].value_counts()) > 2 and len(train[col].value_counts()
                 ) <= float_limit and len(train[col].value_counts()) <= len(train):
                 var_df.loc[var_df['index']==col,'cat'] = 1
             else:
-                if col not in num_bool_vars:
+                if col not in (num_bool_vars + factor_vars):
                     var_df.loc[var_df['index']==col,'numeric'] = 1
     cat_vars = list(var_df[(var_df['cat'] ==1)]['index'])
     continuous_vars = list(var_df[(var_df['numeric'] ==1)]['index'])
+    
     ########  V E R Y    I M P O R T A N T   ###################################################
+    cat_vars_copy = copy.deepcopy(factor_vars) 
+    for cat in cat_vars_copy:
+        if df_preds[cat].dtype==float:
+            continuous_vars.append(cat)
+            factor_vars.remove(cat)
+            var_df.loc[var_df['index']==cat,'dcat'] = 0
+            var_df.loc[var_df['index']==cat,'numeric'] = 1
+        elif len(df_preds[cat].value_counts()) == df_preds.shape[0]:
+            id_vars.append(cat)
+            factor_vars.remove(cat)
+            var_df.loc[var_df['index']==cat,'dcat'] = 0
+            var_df.loc[var_df['index']==cat,'id_col'] = 1
+    
+    sum_all_cols['factor_vars'] = factor_vars
     ##### There are a couple of extra tests you need to do to remove abberations in cat_vars ###
-    cat_vars_copy = copy.deepcopy(cat_vars)
+    cat_vars_copy = copy.deepcopy(cat_vars) 
     for cat in cat_vars_copy:
         if df_preds[cat].dtype==float:
             continuous_vars.append(cat)
@@ -284,6 +301,7 @@ def classify_columns(df_preds, verbose=0):
         print("    ID Columns: %s" %id_vars[:max_cols_to_print])
         print("    Columns that will not be considered in modeling: %s" %cols_delete[:max_cols_to_print])
     ##### now collect all the column types and column names into a single dictionary to return!
+    
     len_sum_all_cols = reduce(add,[len(v) for v in sum_all_cols.values()])
     if len_sum_all_cols == orig_cols_total:
         print('    %d Predictors classified...' %orig_cols_total)
